==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/hal/translations/hal_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation>Engadido HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation>Sobre engadido HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Engadido Qmmp HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Este engadido provén detección de dispositivos extraíbles usando HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Baseado en Solid (librería hardware KDE)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Engadir CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Engadir Volume &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>Opcións do engadido HAL</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Detección de CD de Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Engadir pistas á lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Eliminar pistas da lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Detección de dispositivos extraíbles</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Engadir ficheiros á lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Eliminar ficheiros da lista de reprodución automaticamente</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/hal/translations/hal_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation>Engadido HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation>Sobre engadido HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Engadido Qmmp HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Este engadido provén detección de dispositivos extraíbles usando HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Baseado en Solid (librería hardware KDE)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Engadir CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Engadir Volume &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>Opcións do engadido HAL</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Detección de CD de Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Engadir pistas á lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Eliminar pistas da lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Detección de dispositivos extraíbles</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Engadir ficheiros á lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Eliminar ficheiros da lista de reprodución automaticamente</translation>
    </message>
</context>
</TS>
